@@ -36,7 +36,8 @@ class Network3Medusa():
             print("File size according to `FileInfoQuery`: ", info.size)
         else:
             first = True
-            chunks = pd.read_json(raw_json, lines=True, chunksize=6000000)
+            parsed_json = json.loads(raw_json)
+            chunks = pd.read_json(parsed_json, lines=True, chunksize=6000000)
             print("here")
             for chunk in chunks:
                 if first:
